@@ -1,10 +1,11 @@
 package HTTP::Config;
 
 use strict;
-use URI;
-use vars qw($VERSION);
+use warnings;
 
-$VERSION = "6.00";
+use URI;
+
+our $VERSION = "6.07";
 
 sub new {
     my $class = shift;
