@@ -1,8 +1,9 @@
 package HTTP::Headers::Auth;
 
 use strict;
-use vars qw($VERSION);
-$VERSION = "6.00";
+use warnings;
+
+our $VERSION = "6.07";
 
 use HTTP::Headers;
 
