@@ -1,31 +1,38 @@
 package HTTP::Request::Common;
 
 use strict;
-use vars qw(@EXPORT @EXPORT_OK $VERSION $DYNAMIC_FILE_UPLOAD);
+use warnings;
 
-$DYNAMIC_FILE_UPLOAD ||= 0;  # make it defined (don't know why)
+our $DYNAMIC_FILE_UPLOAD ||= 0;  # make it defined (don't know why)
 
-require Exporter;
-*import = \&Exporter::import;
-@EXPORT =qw(GET HEAD PUT POST);
-@EXPORT_OK = qw($DYNAMIC_FILE_UPLOAD DELETE);
+use Exporter 5.57 'import';
+
+our @EXPORT =qw(GET HEAD PUT POST);
+our @EXPORT_OK = qw($DYNAMIC_FILE_UPLOAD DELETE);
 
 require HTTP::Request;
 use Carp();
 
-$VERSION = "6.03";
+our $VERSION = "6.07";
 
 my $CRLF = "\015\012";   # "\r\n" is not portable
 
 sub GET  { _simple_req('GET',  @_); }
 sub HEAD { _simple_req('HEAD', @_); }
-sub PUT  { _simple_req('PUT' , @_); }
 sub DELETE { _simple_req('DELETE', @_); }
 
-sub POST
+for my $type (qw(PUT POST)) {
+    no strict 'refs';
+    *{ __PACKAGE__ . "::" . $type } = sub {
+        return request_type_with_data($type, @_);
+    };
+}
+
+sub request_type_with_data
 {
-    my $url = shift;
-    my $req = HTTP::Request->new(POST => $url);
+    my $type = shift;
+    my $url  = shift;
+    my $req = HTTP::Request->new($type => $url);
     my $content;
     $content = shift if @_ and ref $_[0];
     my($k, $v);
@@ -83,7 +90,7 @@ sub POST
 	    $content = $url->query;
 
 	    # HTML/4.01 says that line breaks are represented as "CR LF" pairs (i.e., `%0D%0A')
-	    $content =~ s/(?<!%0D)%0A/%0D%0A/g;
+	    $content =~ s/(?<!%0D)%0A/%0D%0A/g if defined($content);
 	}
     }
 
